@@ -40,6 +40,8 @@ def update_package(name):
                     sp.check_output("git pull", shell=True)
                 except sp.CalledProcessError:
                     click.secho("...failed!", bold=True)
+                else:
+                    sp.check_output("pip install -e .", shell=True)
                 finally:
                     os.chdir(wd)
                 break
@@ -51,24 +53,3 @@ def update_package(name):
     new_ver = get_package_version(name)
     if old_ver != new_ver:
         print("...updated {} from {} to {}.".format(name, old_ver, new_ver))
-
-
-@click.command()
-@click.confirmation_option(
-    prompt="Are you sure you want to update your DCOR installation?")
-def update():
-    """Update all DCOR CKAN extensions using pip/git"""
-    for name in [
-        "ckanext-dc_log_view",
-        "ckanext-dc_serve",
-        "ckanext-dc_view",
-        "ckanext-dcor_depot",
-        "ckanext-dcor_schemas",
-        "ckanext-dcor_theme",
-        "dcor_shared",
-        "dcor_control",
-    ]:
-        update_package(name)
-
-    click.secho("Reloading CKAN...", bold=True)
-    sp.check_output("supervisorctl reload", shell=True)
